@@ -1,11 +1,9 @@
 from collections import namedtuple
-from six import with_metaclass
-from rpy2.robjects.packages import (importr, data,
-                                    Package, default_symbol_r2python,
-                                    default_symbol_check_after,
+from rpy2 import robjects
+from rpy2.robjects.packages import (importr,
                                     WeakPackage)
 import warnings
-    
+
 with warnings.catch_warnings():
     warnings.simplefilter("ignore")
     dplyr = importr('dplyr', on_conflict="warn")
@@ -18,16 +16,16 @@ with warnings.catch_warnings():
                         on_conflict="warn",
                         version=dplyr.__version__,
                         symbol_r2python=dplyr._symbol_r2python,
-                        symbol_check_after=dplyr._symbol_check_after)
-TARGET_VERSION = '0.7.5'
-if dplyr.__version__ != TARGET_VERSION:
-    warnings.warn('This was designed againt dplyr version %s but you have %s' % (TARGET_VERSION, dplyr.__version__))
+                        symbol_resolve=dplyr._symbol_resolve)
 
-    
-from rpy2 import robjects
+TARGET_VERSION = '0.8.3'
+if dplyr.__version__ != TARGET_VERSION:
+    warnings.warn('This was designed againt dplyr version %s but you have %s' %
+                  (TARGET_VERSION, dplyr.__version__))
 
 StringInEnv = namedtuple('StringInEnv', 'string env')
 
+
 def _fix_args_inenv(args, env):
     """Use R's lazyeval::as_lazy to evaluate each argument in a sequence as
     code in an environment."""
@@ -39,18 +37,21 @@ def _fix_args_inenv(args, env):
             args_inenv.append(lazyeval.as_lazy(v, env=env))
     return args_inenv
 
+
 def _fix_kwargs_inenv(kwargs, env):
     """Use R's lazyeval::as_lazy to evaluate each value in a dict as
     code in an environment."""
     kwargs_inenv = dict()
-    for k,v in kwargs.items():
+    for k, v in kwargs.items():
         if isinstance(v, StringInEnv):
             kwargs_inenv[k] = lazyeval.as_lazy(v.string, env=v.env)
         else:
             kwargs_inenv[k] = lazyeval.as_lazy(v, env=env)
     return kwargs_inenv
 
-# TODO: _wrap and _pipe have become quite similar (identical ?). Have only one of the two ?
+# TODO: _wrap and _pipe have become quite similar (identical ?).
+#       Have only one of the two ?
+
 
 def _wrap(rfunc, cls, env=robjects.globalenv):
     def func(dataf, *args, **kwargs):
@@ -63,6 +64,7 @@ def _wrap(rfunc, cls, env=robjects.globalenv):
             return cls(res)
     return func
 
+
 def _wrap2(rfunc, cls, env=robjects.globalenv):
     def func(dataf_a, dataf_b, *args, **kwargs):
         res = rfunc(dataf_a, dataf_b,
@@ -73,6 +75,7 @@ def _wrap2(rfunc, cls, env=robjects.globalenv):
             return cls(res)
     return func
 
+
 def _make_pipe(rfunc, cls, env=robjects.globalenv):
     """
     :param rfunc: An R function.
@@ -86,6 +89,7 @@ def _make_pipe(rfunc, cls, env=robjects.globalenv):
         return cls(res)
     return inner
 
+
 def _make_pipe2(rfunc, cls, env=robjects.globalenv):
     """
     :param rfunc: An R function.
@@ -97,11 +101,12 @@ def _make_pipe2(rfunc, cls, env=robjects.globalenv):
         return cls(res)
     return inner
 
+
 class DataFrame(robjects.DataFrame):
     """DataFrame object extending the object of the same name in
     `rpy2.robjects.vectors` with functionalities defined in the R
     package `dplyr`."""
-    
+
     def __rshift__(self, other):
         return other(self)
 
@@ -117,7 +122,7 @@ class DataFrame(robjects.DataFrame):
         """
         Call the function `collapse` in the R package `dplyr`.
         """
-        
+
         cls = type(self)
         return cls(dplyr.collapse(self, *args, **kwargs))
 
@@ -213,47 +218,53 @@ transmute_all = _make_pipe(dplyr.transmute_all, DataFrame)
 transmute_if = _make_pipe(dplyr.transmute_if, DataFrame)
 transmute_at = _make_pipe(dplyr.transmute_at, DataFrame)
 
-# Functions for databases
 
+# Functions for databases
 class DataSource(robjects.ListVector):
     """ Source of data tables (e.g., in a schema in a relational database). """
-    
+
     @property
     def tablenames(self):
         """ Call the R function dplyr::src_tbls() and return a vector
         of table names."""
         return tuple(dplyr.src_tbls(self))
-    
+
     def get_table(self, name):
         """ "Get" table from a source (R dplyr's function `tbl`). """
         return DataFrame(tbl(self, name))
-    
+
+
 src = dplyr.src
 src_tbls = dplyr.src_tbls
 
 src_local = dplyr.src_local
 src_df = dplyr.src_df
 
+
 def src_mysql(*args, **kwargs):
     res = dplyr.src_mysql(*args, **kwargs)
     return DataSource(res)
 
+
 def src_postgres(*args, **kwargs):
     res = dplyr.src_postgres(*args, **kwargs)
     return DataSource(res)
 
+
 def src_sqlite(*args, **kwargs):
     res = dplyr.src_sqlite(*args, **kwargs)
     return DataSource(res)
 
+
 def copy_to(*args, **kwargs):
     res = dplyr.copy_to(*args, **kwargs)
     return DataFrame(res)
-    
-# Generic to create a data table
 
+
+# Generic to create a data table
 tbl = dplyr.tbl
 
+
 # TODO: wrapper classes for the output of the following two function.
 explain = dplyr.explain
 show_query = dplyr.show_query
